Skip to contents

Create animated biplot on samples in a biplot

Usage

moveplot(
  bp,
  time.var,
  group.var,
  move = TRUE,
  hulls = TRUE,
  scale.var = 5,
  shadow = FALSE
)

Arguments

bp

biplot object from biplotEZ

time.var

time variable

group.var

group variable

move

whether to animate (TRUE) or facet (FALSE) samples, according to time.var

hulls

whether to display sample points or convex hulls

scale.var

scaling the vectors representing the variables

shadow

whether the animation will keep past states (only when hulls = FALSE)

Value

bp

Returns the elements of the biplot object bp from biplotEZ.

plot

An animated or a facet of biplots based on the dynamic frame.

Examples

data(Africa_climate)
bp <- biplot(Africa_climate, scaled = TRUE) |> PCA()

# Convex hulls facet plot
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = TRUE, move = FALSE)

#> Object of class biplot, based on 960 samples and 9 variables.
#> 6 numeric variables.
#> 3 categorical variables.

# Samples facet plot
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = FALSE, move = FALSE)

#> Object of class biplot, based on 960 samples and 9 variables.
#> 6 numeric variables.
#> 3 categorical variables.

# Specifying colours with colour palette in biplotEZ
bp <- biplot(Africa_climate, scaled = TRUE, group.aes = Africa_climate$Region) |>
PCA() |> samples(col = RColorBrewer::brewer.pal(10, "Paired"))
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = TRUE, move = FALSE)

#> Object of class biplot, based on 960 samples and 9 variables.
#> 6 numeric variables.
#> 3 categorical variables.

# Specifying plotting characters for grouping variable in biplotEZ
bp <- biplot(Africa_climate, scaled = TRUE, group.aes = Africa_climate$Region) |>
PCA() |> samples(pch = c(19, 21, 3))
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = FALSE, move = FALSE)

#> Object of class biplot, based on 960 samples and 9 variables.
#> 6 numeric variables.
#> 3 categorical variables.

# Specifying opacity of plotting characters and size of variable lables
bp <- biplot(Africa_climate, scaled = TRUE, group.aes = Africa_climate$Region) |>
PCA() |> samples(opacity = 0.4) |> axes(label.cex = 1.2)
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = FALSE, move = FALSE)

#> Object of class biplot, based on 960 samples and 9 variables.
#> 6 numeric variables.
#> 3 categorical variables.

# Specifying colours manually in biplotEZ
bp <- biplot(Africa_climate, scaled = TRUE, group.aes = Africa_climate$Region) |>
PCA() |> samples(col = c("firebrick4", "indianred3", "tomato", "sandybrown",
 "khaki1", "palegreen1", "darkseagreen2", "mediumaquamarine", "deepskyblue4", "mediumpurple4"))
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = TRUE, move = FALSE)

#> Object of class biplot, based on 960 samples and 9 variables.
#> 6 numeric variables.
#> 3 categorical variables.

# Extracting measures of fit of PCA
bp <- biplot(Africa_climate, scaled = TRUE) |> PCA() |> fit.measures()
bp <- bp |> moveplot(time.var = "Year", group.var = "Region", hulls = TRUE, move = FALSE)

bp$quality
#> [1] 0.6521806
bp$axis.predictivity
#>    AccPrec   DailyEva       Temp   SoilMois       SPI6       wind 
#> 0.80052267 0.74091999 0.67032024 0.90091529 0.06221102 0.73819448 

# Convex hulls move plot
# \donttest{
if(interactive()) {
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = TRUE, move = TRUE)}# }

# Samples move plot with shadows
# \donttest{
if(interactive()) {
bp |> moveplot(time.var = "Year", group.var = "Region", hulls = FALSE, move = TRUE, shadow = TRUE)}# }

# CVA biplot
bp <- biplot(Africa_climate, scaled = TRUE) |> CVA(class = Africa_climate$Region)
bp |> moveplot2(group.var = "Region", time.var = "Year", move = FALSE)

#> Object of class biplot, based on 960 samples and 9 variables.
#> 6 numeric variables.
#> 3 categorical variables.
#> 10 classes: ARP CAF ESAF MDG MED NEAF SAH SEAF WAF WSAF 
#> Error in x$quality * 100: non-numeric argument to binary operator

# Extracting measures of fit of CVA
bp <- biplot(Africa_climate, scaled = TRUE) |> CVA(classes = Africa_climate$Region) |> fit.measures()
bp <- bp |> moveplot(time.var = "Year", group.var = "Region", hulls = TRUE, move = FALSE)

bp$quality
#> $`canonical variables`
#> [1] 0.9689896
#> 
#> $`original variables`
#> [1] 0.8347221
#> 
bp$axis.predictivity
#>   AccPrec  DailyEva      Temp  SoilMois      SPI6      wind 
#> 0.8407746 0.9942865 0.1229343 0.9947983 0.2219328 0.9105104 
bp$within.class.axis.predictivity
#>      AccPrec     DailyEva         Temp     SoilMois         SPI6         wind 
#> 0.0438434841 0.7825372406 0.0050764080 0.3595595684 0.0006005944 0.1452740241 
bp$within.class.sample.predictivity
#>            1            2            3            4            5            6 
#> 0.0290418630 0.0441606823 0.0209780552 0.0108616316 0.1883830458 0.0330856832 
#>            7            8            9           10           11           12 
#> 0.1059396186 0.1355096126 0.0376134576 0.0003570811 0.0222218960 0.0150887736 
#>           13           14           15           16           17           18 
#> 0.0477335949 0.0321365849 0.0020450039 0.1505318467 0.3901833222 0.0355752540 
#>           19           20           21           22           23           24 
#> 0.0266442717 0.0276036168 0.1496821671 0.0040472136 0.0311349841 0.0638899116 
#>           25           26           27           28           29           30 
#> 0.0166393158 0.0539687398 0.0697437657 0.0268591153 0.0176345827 0.0205837395 
#>           31           32           33           34           35           36 
#> 0.0206123686 0.0938550775 0.1679640784 0.0269332552 0.0513165092 0.1189336201 
#>           37           38           39           40           41           42 
#> 0.0694589603 0.0424965497 0.1145316634 0.0058305831 0.1388761641 0.0332348854 
#>           43           44           45           46           47           48 
#> 0.0221637931 0.0625260926 0.0643755051 0.0099270221 0.0115387085 0.0587982006 
#>           49           50           51           52           53           54 
#> 0.0699030228 0.0094393505 0.0994943633 0.0269563173 0.0701772870 0.0293172814 
#>           55           56           57           58           59           60 
#> 0.0344220437 0.0527778645 0.0804922264 0.0108095673 0.0562712091 0.0552638947 
#>           61           62           63           64           65           66 
#> 0.1115977023 0.0939339517 0.0559358591 0.0167300122 0.0355479568 0.0232978617 
#>           67           68           69           70           71           72 
#> 0.0244476737 0.0572972767 0.0698058264 0.0481022309 0.1390530805 0.0306601522 
#>           73           74           75           76           77           78 
#> 0.0498162044 0.0495946218 0.0893299344 0.0270622254 0.0629092733 0.0417581147 
#>           79           80           81           82           83           84 
#> 0.0339580112 0.0561145221 0.0317775523 0.0134275969 0.0417997278 0.0679808768 
#>           85           86           87           88           89           90 
#> 0.1509117035 0.2548884155 0.1836766238 0.0381412755 0.0673334310 0.0601859247 
#>           91           92           93           94           95           96 
#> 0.0348637359 0.0260190063 0.0377918709 0.0066149606 0.0709408727 0.0489228339 
#>           97           98           99          100          101          102 
#> 0.1558015319 0.3432008007 0.2711206326 0.4950397387 0.7174014989 0.0062121195 
#>          103          104          105          106          107          108 
#> 0.5161439828 0.6341350562 0.0098585075 0.1800561328 0.0024230810 0.3861994758 
#>          109          110          111          112          113          114 
#> 0.7851332291 0.9551900975 0.6800023955 0.3629444592 0.9019186052 0.6771396036 
#>          115          116          117          118          119          120 
#> 0.5242207366 0.4577177753 0.1446302004 0.0791993419 0.2322303422 0.2594537618 
#>          121          122          123          124          125          126 
#> 0.3412530565 0.6064287423 0.4209058312 0.1177530870 0.1693814394 0.4307362179 
#>          127          128          129          130          131          132 
#> 0.5755771693 0.5567689199 0.6371964071 0.1629209983 0.2125917852 0.0759236690 
#>          133          134          135          136          137          138 
#> 0.6802424480 0.7645110007 0.5518966602 0.0154218840 0.2127018674 0.2914534231 
#>          139          140          141          142          143          144 
#> 0.5019032709 0.3827236602 0.5209178930 0.3184385074 0.1649514452 0.0439371660 
#>          145          146          147          148          149          150 
#> 0.4967479024 0.8750741217 0.8884262507 0.5282323201 0.7231511835 0.4966533147 
#>          151          152          153          154          155          156 
#> 0.7994943230 0.8257020883 0.1834871618 0.4021361471 0.6792843765 0.3800951337 
#>          157          158          159          160          161          162 
#> 0.1438626604 0.4149041580 0.7986731873 0.4536526373 0.4589156852 0.4835277877 
#>          163          164          165          166          167          168 
#> 0.6799498082 0.8058770884 0.7981180039 0.4313486277 0.8315612588 0.0632141877 
#>          169          170          171          172          173          174 
#> 0.0621753546 0.5359889115 0.7080053153 0.0967813108 0.1911939760 0.1773671260 
#>          175          176          177          178          179          180 
#> 0.3924576995 0.3205253425 0.3681799772 0.5133536951 0.5118696780 0.3416769832 
#>          181          182          183          184          185          186 
#> 0.7698782934 0.8792576906 0.5291519160 0.2570930544 0.0316314214 0.0370678409 
#>          187          188          189          190          191          192 
#> 0.2026968942 0.1712948959 0.4392390396 0.3941353269 0.3931349103 0.0723736093 
#>          193          194          195          196          197          198 
#> 0.0997630784 0.0164630666 0.8544795686 0.9210113991 0.4553904924 0.3988264303 
#>          199          200          201          202          203          204 
#> 0.3137117984 0.4915105599 0.7566321790 0.8468989618 0.1766081629 0.0859713131 
#>          205          206          207          208          209          210 
#> 0.7969929566 0.5262824713 0.2002200238 0.8538200172 0.3194774944 0.3506020985 
#>          211          212          213          214          215          216 
#> 0.4469932804 0.8030684200 0.8528524108 0.7774162207 0.4616790972 0.0499586627 
#>          217          218          219          220          221          222 
#> 0.4873199961 0.7074683930 0.7945747399 0.6143722490 0.1714718642 0.2823122546 
#>          223          224          225          226          227          228 
#> 0.2681429095 0.6057108479 0.8644137154 0.4544799098 0.1500282347 0.1555134200 
#>          229          230          231          232          233          234 
#> 0.7324457076 0.5705575656 0.8390159199 0.7150867374 0.4888805972 0.5194433183 
#>          235          236          237          238          239          240 
#> 0.4453543465 0.5963218681 0.5573190576 0.3609856964 0.0585483713 0.2858193558 
#>          241          242          243          244          245          246 
#> 0.2143060597 0.7395482846 0.7623750000 0.9103653894 0.4523176156 0.1872966962 
#>          247          248          249          250          251          252 
#> 0.4094819319 0.5954859514 0.5076922455 0.5868140585 0.2364109988 0.2846545428 
#>          253          254          255          256          257          258 
#> 0.4118020413 0.0275764556 0.6288377658 0.8001171511 0.2393002326 0.2893096171 
#>          259          260          261          262          263          264 
#> 0.1856885220 0.4355394751 0.5485354482 0.5176633152 0.0328468750 0.5524400612 
#>          265          266          267          268          269          270 
#> 0.3425990068 0.0946553031 0.8590854063 0.9412966056 0.1888004663 0.4011058514 
#>          271          272          273          274          275          276 
#> 0.4438888973 0.5731655282 0.6280415287 0.5540547803 0.1298400073 0.4134224094 
#>          277          278          279          280          281          282 
#> 0.2277245401 0.3679566827 0.8866299613 0.6863177862 0.4057897532 0.4757445900 
#>          283          284          285          286          287          288 
#> 0.5027117153 0.4457159679 0.4999124017 0.3902662354 0.0300175345 0.1168899017 
#>          289          290          291          292          293          294 
#> 0.4076465498 0.4496485590 0.6241399615 0.8870191837 0.8612983514 0.5549520397 
#>          295          296          297          298          299          300 
#> 0.1629650488 0.4077723802 0.2912623408 0.7765659119 0.9898214073 0.6728813115 
#>          301          302          303          304          305          306 
#> 0.4334274325 0.3950059088 0.2605217626 0.7544834419 0.5462432767 0.1546613961 
#>          307          308          309          310          311          312 
#> 0.5019169828 0.2221762841 0.1826190983 0.7629797985 0.9578030648 0.6675565316 
#>          313          314          315          316          317          318 
#> 0.4865859655 0.3967408904 0.7967858596 0.8591403723 0.6707329552 0.6747291622 
#>          319          320          321          322          323          324 
#> 0.2237957665 0.1138462158 0.4609154985 0.5935503007 0.9089673386 0.5655031799 
#>          325          326          327          328          329          330 
#> 0.6428385295 0.3944666901 0.4850637690 0.1518248798 0.9158373829 0.6564085874 
#>          331          332          333          334          335          336 
#> 0.5020992442 0.2696191630 0.1394228968 0.7478296185 0.9361615379 0.4023183128 
#>          337          338          339          340          341          342 
#> 0.4656906745 0.2715737125 0.6118150230 0.4910126921 0.7565057435 0.4349190747 
#>          343          344          345          346          347          348 
#> 0.5222020840 0.3469073016 0.3464066568 0.3406761197 0.8014695696 0.5511855509 
#>          349          350          351          352          353          354 
#> 0.3803286357 0.4629419405 0.4415360594 0.2176906018 0.2771212452 0.7140713653 
#>          355          356          357          358          359          360 
#> 0.6026665505 0.1457352344 0.2688610027 0.6237583310 0.8316603072 0.4058168701 
#>          361          362          363          364          365          366 
#> 0.4258341704 0.0213882431 0.4071473615 0.5639579572 0.2864437731 0.8027343974 
#>          367          368          369          370          371          372 
#> 0.7115814391 0.4566855436 0.2825861075 0.8320606727 0.8214251248 0.4916069715 
#>          373          374          375          376          377          378 
#> 0.5262357612 0.2923565501 0.7279339509 0.7487129222 0.7878139287 0.7100907618 
#>          379          380          381          382          383          384 
#> 0.7697923219 0.2383490644 0.0485667905 0.4486254058 0.5607480368 0.2377597044 
#>          385          386          387          388          389          390 
#> 0.1199051805 0.1484372230 0.4509134134 0.6649879781 0.9056096039 0.0770265499 
#>          391          392          393          394          395          396 
#> 0.1026439413 0.2433223059 0.2695338060 0.6644779534 0.1268669284 0.1256225230 
#>          397          398          399          400          401          402 
#> 0.0522815821 0.4076571871 0.2308456428 0.6605117462 0.8247325168 0.0157572858 
#>          403          404          405          406          407          408 
#> 0.1888953415 0.2215513600 0.5278746695 0.5520231697 0.0860273220 0.0921298522 
#>          409          410          411          412          413          414 
#> 0.3515735735 0.0589796994 0.0686444915 0.2644488612 0.2024486419 0.3018389433 
#>          415          416          417          418          419          420 
#> 0.0937870260 0.1975692762 0.2271848597 0.9288969488 0.0564421984 0.0762917079 
#>          421          422          423          424          425          426 
#> 0.0220837747 0.4461131168 0.2780297518 0.1960697376 0.5838002909 0.0848559567 
#>          427          428          429          430          431          432 
#> 0.0725134174 0.0738922643 0.0739940477 0.7704884237 0.1361024050 0.3105314946 
#>          433          434          435          436          437          438 
#> 0.4563547566 0.4988547455 0.2884551588 0.2536055703 0.7165798863 0.0865780285 
#>          439          440          441          442          443          444 
#> 0.0523285950 0.1250819487 0.0925567559 0.3304776532 0.1931344503 0.1247061781 
#>          445          446          447          448          449          450 
#> 0.1485292305 0.2208543857 0.2107260596 0.3378128465 0.6548074578 0.1161566843 
#>          451          452          453          454          455          456 
#> 0.2053130748 0.1315015234 0.4457372676 0.7152835391 0.0636169724 0.0127987232 
#>          457          458          459          460          461          462 
#> 0.0178574865 0.0436693396 0.3723886378 0.8590603402 0.0325956768 0.0326559575 
#>          463          464          465          466          467          468 
#> 0.0231547556 0.0976798561 0.4163885728 0.7314199342 0.0739126026 0.2034180081 
#>          469          470          471          472          473          474 
#> 0.1455181515 0.3582979848 0.0984117583 0.8340348280 0.4077082450 0.1700998875 
#>          475          476          477          478          479          480 
#> 0.0375598986 0.1108931826 0.3323229837 0.4985715546 0.1502669353 0.1040174632 
#>          481          482          483          484          485          486 
#> 0.3834952366 0.4143288387 0.0751229045 0.1347078473 0.4716649475 0.0957285573 
#>          487          488          489          490          491          492 
#> 0.0932395194 0.1310779944 0.1427375020 0.4362386981 0.1814603977 0.2333238463 
#>          493          494          495          496          497          498 
#> 0.5777424257 0.5535791148 0.1720967228 0.1302669943 0.7139974872 0.0228468419 
#>          499          500          501          502          503          504 
#> 0.0005180615 0.0489844461 0.2018042231 0.4394460199 0.2034049108 0.2792372936 
#>          505          506          507          508          509          510 
#> 0.4953483579 0.6530921777 0.5072495223 0.0973815770 0.4570912985 0.0426960305 
#>          511          512          513          514          515          516 
#> 0.0331810712 0.0295032937 0.4663381662 0.3682236602 0.3461821264 0.7266334904 
#>          517          518          519          520          521          522 
#> 0.6790685324 0.6601200574 0.6348948084 0.0656881195 0.6438877320 0.0236469589 
#>          523          524          525          526          527          528 
#> 0.0203044041 0.0592024541 0.7489665846 0.3395892669 0.0757381703 0.3577285442 
#>          529          530          531          532          533          534 
#> 0.5899968866 0.5746213265 0.2464337105 0.2376127035 0.0291743592 0.1428133074 
#>          535          536          537          538          539          540 
#> 0.0060246995 0.0023091060 0.0750571574 0.1810109780 0.0126790800 0.2996970517 
#>          541          542          543          544          545          546 
#> 0.7137618683 0.7134514009 0.6953405917 0.1279309330 0.2672933820 0.0431007442 
#>          547          548          549          550          551          552 
#> 0.0029243072 0.0300382324 0.1981242576 0.4815535606 0.1616915426 0.4514994790 
#>          553          554          555          556          557          558 
#> 0.3280606332 0.6533524064 0.1522654685 0.1392778404 0.0512963057 0.0214998689 
#>          559          560          561          562          563          564 
#> 0.0868512137 0.0168269809 0.4875581100 0.2084352479 0.0359894371 0.2263665473 
#>          565          566          567          568          569          570 
#> 0.5049793234 0.4604004362 0.3604388010 0.2472208458 0.5512314342 0.0278617886 
#>          571          572          573          574          575          576 
#> 0.0200140977 0.1052735726 0.4842392230 0.1903879965 0.1925000331 0.5145838020 
#>          577          578          579          580          581          582 
#> 0.1351105430 0.1825742463 0.3040571228 0.4187160614 0.0516586981 0.0695722317 
#>          583          584          585          586          587          588 
#> 0.2097247621 0.4574590148 0.1899383892 0.0534541823 0.0663265934 0.0891888265 
#>          589          590          591          592          593          594 
#> 0.1411182218 0.0502950989 0.0539534261 0.0177644210 0.0145633256 0.0666246906 
#>          595          596          597          598          599          600 
#> 0.1487417267 0.1981495712 0.2097612015 0.0684699592 0.0295676649 0.0542388249 
#>          601          602          603          604          605          606 
#> 0.0752186022 0.1580035291 0.2256241261 0.0675867333 0.0140004544 0.0286738901 
#>          607          608          609          610          611          612 
#> 0.1464436662 0.3783831656 0.3593493147 0.0959714806 0.0917986081 0.0992685341 
#>          613          614          615          616          617          618 
#> 0.0859426701 0.1351545349 0.1532587068 0.0707854195 0.0155450760 0.0532830355 
#>          619          620          621          622          623          624 
#> 0.1400162361 0.2811173806 0.2398603256 0.1713099838 0.0235574412 0.1491494146 
#>          625          626          627          628          629          630 
#> 0.1225472290 0.1369448688 0.2949987382 0.0451513378 0.0182555505 0.0575194775 
#>          631          632          633          634          635          636 
#> 0.1281156394 0.2016453671 0.1582369698 0.0849936321 0.0179904630 0.0786659809 
#>          637          638          639          640          641          642 
#> 0.0955339546 0.2054563094 0.3049728622 0.0483189028 0.0631967821 0.0479448526 
#>          643          644          645          646          647          648 
#> 0.0837440868 0.1830100923 0.1638225503 0.1178054124 0.0543404804 0.0751053194 
#>          649          650          651          652          653          654 
#> 0.0692615465 0.0666789835 0.1239856841 0.0084924467 0.0100090428 0.0774825395 
#>          655          656          657          658          659          660 
#> 0.0921128980 0.2087258034 0.1888217886 0.0544077279 0.0198509323 0.0699095657 
#>          661          662          663          664          665          666 
#> 0.1939399071 0.2003748920 0.3838561800 0.0093730010 0.0135643404 0.0434970804 
#>          667          668          669          670          671          672 
#> 0.0923117740 0.1727876527 0.2364329547 0.1906058611 0.0929538211 0.0729974356 
#>          673          674          675          676          677          678 
#> 0.6623931906 0.8948297321 0.1385015501 0.0103741504 0.4411413418 0.0200104590 
#>          679          680          681          682          683          684 
#> 0.2841652977 0.4185170471 0.5132903331 0.9534869675 0.5201361663 0.4076427014 
#>          685          686          687          688          689          690 
#> 0.5128946616 0.1109436243 0.0077700947 0.0184016701 0.2285259660 0.1181987851 
#>          691          692          693          694          695          696 
#> 0.1891309382 0.1925128521 0.3677679914 0.6825888466 0.3013596855 0.1516780780 
#>          697          698          699          700          701          702 
#> 0.1832318118 0.8424178549 0.0107091831 0.1287332667 0.7460811880 0.2823878117 
#>          703          704          705          706          707          708 
#> 0.1780387693 0.4223746204 0.3745862556 0.4385482401 0.3352536317 0.3129378612 
#>          709          710          711          712          713          714 
#> 0.9619787769 0.4520642414 0.3558907125 0.1419785057 0.5834327206 0.3505596347 
#>          715          716          717          718          719          720 
#> 0.1992511674 0.3248563587 0.6634116670 0.8815385981 0.4305524546 0.6276220015 
#>          721          722          723          724          725          726 
#> 0.7932959078 0.3145665701 0.2604819109 0.4158827435 0.6221578661 0.1833552205 
#>          727          728          729          730          731          732 
#> 0.2687774278 0.2687847160 0.3565237321 0.5302824344 0.4065735848 0.3775469145 
#>          733          734          735          736          737          738 
#> 0.5080561062 0.2998856884 0.1068122450 0.2197495627 0.0645960108 0.1607445213 
#>          739          740          741          742          743          744 
#> 0.1102541092 0.1120281923 0.1120180743 0.3488769498 0.3888653258 0.5928739207 
#>          745          746          747          748          749          750 
#> 0.8887941806 0.1008668562 0.1500100425 0.7599037477 0.5839225186 0.4362169514 
#>          751          752          753          754          755          756 
#> 0.2188171071 0.4538058180 0.2354228702 0.5288509987 0.3074178645 0.2957045022 
#>          757          758          759          760          761          762 
#> 0.2038166839 0.2573044264 0.0314507788 0.1203689317 0.6028348945 0.5294679378 
#>          763          764          765          766          767          768 
#> 0.2800852400 0.2381400596 0.4024114032 0.9160478550 0.2067032352 0.5295049300 
#>          769          770          771          772          773          774 
#> 0.2389870341 0.2115103964 0.5912489126 0.7959163227 0.2858434894 0.4649034775 
#>          775          776          777          778          779          780 
#> 0.1756906565 0.0085785392 0.5864404371 0.8906082782 0.1825752744 0.0567556399 
#>          781          782          783          784          785          786 
#> 0.3108029436 0.4905930486 0.3829125144 0.4669607574 0.0412644776 0.1375908412 
#>          787          788          789          790          791          792 
#> 0.2401949775 0.1090809212 0.1084409462 0.6779907111 0.2428428001 0.0982766898 
#>          793          794          795          796          797          798 
#> 0.0600221287 0.1349177820 0.0725978301 0.3527039551 0.2596768420 0.4097875905 
#>          799          800          801          802          803          804 
#> 0.1098024505 0.0538645638 0.1186369284 0.8004202953 0.1403196215 0.0050725267 
#>          805          806          807          808          809          810 
#> 0.2569035472 0.3845567960 0.3932830566 0.4217216005 0.4612788697 0.2043397508 
#>          811          812          813          814          815          816 
#> 0.0552793248 0.0151153883 0.1345687761 0.1401985135 0.1971382220 0.0340603904 
#>          817          818          819          820          821          822 
#> 0.0749116494 0.5855829165 0.5514845066 0.6128021937 0.2724782737 0.0513980999 
#>          823          824          825          826          827          828 
#> 0.0298069575 0.1914593994 0.3998450679 0.6241576852 0.2673169586 0.0350778840 
#>          829          830          831          832          833          834 
#> 0.1021625643 0.2526715744 0.3894269176 0.0209410977 0.3996069977 0.3315654665 
#>          835          836          837          838          839          840 
#> 0.1423092957 0.2487757080 0.1380024618 0.8303229671 0.2566972361 0.0137648216 
#>          841          842          843          844          845          846 
#> 0.1474848029 0.3641634691 0.3743888085 0.1938637728 0.0480755886 0.2882791327 
#>          847          848          849          850          851          852 
#> 0.1592881733 0.0326604398 0.0420064925 0.6992789536 0.2890323373 0.0117200084 
#>          853          854          855          856          857          858 
#> 0.0380130895 0.2901925213 0.3066936553 0.0269369575 0.1411650864 0.2312499237 
#>          859          860          861          862          863          864 
#> 0.1658676134 0.0468438218 0.0651273899 0.9065954542 0.2862658317 0.0324760019 
#>          865          866          867          868          869          870 
#> 0.5796032942 0.7660862597 0.8482690867 0.9947022896 0.6836825110 0.2478224840 
#>          871          872          873          874          875          876 
#> 0.4566192846 0.7517034672 0.9256301437 0.9704209414 0.0096349197 0.1911126429 
#>          877          878          879          880          881          882 
#> 0.2446460834 0.6127790373 0.7845116524 0.7762327088 0.2180545922 0.4932193468 
#>          883          884          885          886          887          888 
#> 0.4649972486 0.5019071940 0.9012852730 0.9265574016 0.5143646425 0.2389117886 
#>          889          890          891          892          893          894 
#> 0.1504378414 0.7793623326 0.5304591262 0.0094925949 0.1497726594 0.3675774411 
#>          895          896          897          898          899          900 
#> 0.4164898030 0.6359342391 0.8197155764 0.9434729632 0.8104303544 0.5179749664 
#>          901          902          903          904          905          906 
#> 0.6638170983 0.7093395026 0.8060555666 0.4233027221 0.5828397036 0.4981662493 
#>          907          908          909          910          911          912 
#> 0.7469440582 0.7150436955 0.7514764425 0.4686553521 0.7681202422 0.1815957448 
#>          913          914          915          916          917          918 
#> 0.2472137599 0.6818817650 0.7971904329 0.8948212302 0.3428626038 0.4333702240 
#>          919          920          921          922          923          924 
#> 0.5310213675 0.6668760945 0.9187276622 0.2080077407 0.4502956537 0.7471155964 
#>          925          926          927          928          929          930 
#> 0.9011603472 0.7688735019 0.8320770726 0.8818688949 0.0177740016 0.5852824804 
#>          931          932          933          934          935          936 
#> 0.6345528095 0.8455199419 0.4876703909 0.3942120757 0.0762442457 0.1951104971 
#>          937          938          939          940          941          942 
#> 0.7761258231 0.5076261641 0.7230441054 0.8542295630 0.0669366751 0.4981894724 
#>          943          944          945          946          947          948 
#> 0.7128662255 0.8541401097 0.7917579768 0.6951074027 0.3899319771 0.2661727521 
#>          949          950          951          952          953          954 
#> 0.3035417316 0.4320682192 0.7608905868 0.8465784322 0.3666715374 0.5687076821 
#>          955          956          957          958          959          960 
#> 0.6891854137 0.8035794553 0.7176242367 0.5910043457 0.3945622650 0.0716503338