Move plot 2
moveplot2.RdCreate animated biplot on samples and variables in a biplot
Usage
moveplot2(
bp,
time.var,
group.var,
move = TRUE,
hulls = TRUE,
scale.var = 5,
align.time = NA,
reflect = NA
)Arguments
- bp
biplot object from biplotEZ
- time.var
name of the time variable, given as a character string. Must be a factor column of the data supplied to
biplot(); the order of its levels gives the order of the time slices and levels without observations are dropped. A numeric (e.g. integer year) or character column stops with an error, see Details.- group.var
name of the group variable, given as a character string. Must be a factor column of the data supplied to
biplot().- move
whether to animate (TRUE) or facet (FALSE) samples and variables, according to time.var
- hulls
whether to display sample points or convex hulls. A hull requires at least three non-collinear observations per group per level of
time.var; groups with fewer are displayed as points instead.- scale.var
scaling the vectors representing the variables
- align.time
a vector specifying the levels of time.var for which the biplots should be reflected. Default (NA) reflects none.
- reflect
a character vector, of the same length as align.time, specifying the reflection to apply at each corresponding time point in align.time. One of "x" to reverse the direction of the x-axis (horizontal flip), "y" to reverse the direction of the y-axis (vertical flip) and "xy" for both. This follows
reflect.axisofbiplotEZ::reflect(). Default (NA) applies no reflection.
Value
- bp
Returns the elements of the biplot object
bpfrombiplotEZ.- plot
An animated or a facet of biplots based on the dynamic frame.
Details
time.var and group.var must both be factors. biplot() treats every numeric
column as a variable of the biplot, so a time variable stored as a number (e.g. an integer year)
has to be converted with factor() before biplot() is called, not afterwards.
Missing values are handled by biplot(), which removes every row containing an NA
in any column (including time.var and group.var) with a warning. The plot is
constructed from the remaining rows.
Examples
data(Africa_climate)
bp <- biplot(Africa_climate, scaled = TRUE) |> PCA()
# \donttest{
if(interactive()) {
bp <- bp |> moveplot2(time.var = "Year", group.var = "Region", hulls = TRUE, move = TRUE)}# }
# Extracting measures of fit for PCA
bp <- bp |> moveplot2(time.var = "Year", group.var = "Region", hulls = TRUE, move = FALSE)
bp$quality
#>
#>
#> Table: Biplot qualities per time slice
#>
#> | Time slice | Quality |
#> |:----------:|:-------:|
#> | 1950 | 0.657 |
#> | 1960 | 0.691 |
#> | 1970 | 0.690 |
#> | 1980 | 0.689 |
#> | 1990 | 0.674 |
#> | 2000 | 0.685 |
#> | 2010 | 0.677 |
#> | 2020 | 0.652 |
bp$axis.predictivity
#>
#>
#> Table: Axis predictivities per time slice
#>
#> | Time slice | AccPrec | DailyEva | Temp | SoilMois | SPI6 | wind |
#> |:----------:|:-------:|:--------:|:-----:|:--------:|:-----:|:-----:|
#> | 1950 | 0.754 | 0.757 | 0.527 | 0.887 | 0.420 | 0.596 |
#> | 1960 | 0.789 | 0.718 | 0.683 | 0.919 | 0.305 | 0.735 |
#> | 1970 | 0.777 | 0.638 | 0.726 | 0.896 | 0.389 | 0.715 |
#> | 1980 | 0.801 | 0.781 | 0.607 | 0.887 | 0.296 | 0.760 |
#> | 1990 | 0.824 | 0.783 | 0.583 | 0.909 | 0.221 | 0.723 |
#> | 2000 | 0.760 | 0.617 | 0.727 | 0.905 | 0.535 | 0.571 |
#> | 2010 | 0.763 | 0.772 | 0.632 | 0.873 | 0.293 | 0.727 |
#> | 2020 | 0.784 | 0.794 | 0.547 | 0.895 | 0.149 | 0.743 |
# Extracting measures of fit for CVA
bp <- biplot(Africa_climate) |> CVA(classes = Africa_climate$Region)
bp <- bp |> moveplot2(time.var = "Year", group.var = "Region", hulls = TRUE, move = FALSE)
bp$quality
#>
#>
#> Table: Biplot qualities per time slice
#>
#> | Time slice | Quality.canonical.variables | Quality.original.variables |
#> |:----------:|:---------------------------:|:--------------------------:|
#> | 1950 | 0.910 | 0.865 |
#> | 1960 | 0.955 | 0.904 |
#> | 1970 | 0.962 | 0.904 |
#> | 1980 | 0.939 | 0.889 |
#> | 1990 | 0.977 | 0.899 |
#> | 2000 | 0.935 | 0.896 |
#> | 2010 | 0.967 | 0.887 |
#> | 2020 | 0.950 | 0.892 |
bp$axis.predictivity
#>
#>
#> Table: Axis predictivities per time slice
#>
#> | Time slice | AccPrec | DailyEva | Temp | SoilMois | SPI6 | wind |
#> |:----------:|:-------:|:--------:|:-----:|:--------:|:-----:|:-----:|
#> | 1950 | 0.760 | 0.952 | 0.084 | 0.947 | 0.248 | 0.930 |
#> | 1960 | 0.859 | 0.990 | 0.131 | 0.992 | 0.343 | 0.912 |
#> | 1970 | 0.838 | 0.992 | 0.116 | 0.997 | 0.486 | 0.917 |
#> | 1980 | 0.804 | 0.993 | 0.093 | 0.995 | 0.284 | 0.920 |
#> | 1990 | 0.823 | 0.992 | 0.150 | 0.992 | 0.260 | 0.907 |
#> | 2000 | 0.841 | 0.993 | 0.131 | 0.995 | 0.093 | 0.895 |
#> | 2010 | 0.823 | 0.994 | 0.154 | 0.992 | 0.331 | 0.884 |
#> | 2020 | 0.827 | 0.993 | 0.130 | 0.994 | 0.055 | 0.914 |
bp$within.class.axis.predictivity
#>
#>
#> Table: Class axis predictivities per time slice
#>
#> | Time slice | AccPrec | DailyEva | Temp | SoilMois | SPI6 | wind |
#> |:----------:|:-------:|:--------:|:-----:|:--------:|:-----:|:-----:|
#> | 1950 | 0.042 | 0.746 | 0.003 | 0.317 | 0.061 | 0.145 |
#> | 1960 | 0.042 | 0.713 | 0.004 | 0.285 | 0.027 | 0.095 |
#> | 1970 | 0.041 | 0.751 | 0.005 | 0.327 | 0.012 | 0.154 |
#> | 1980 | 0.047 | 0.674 | 0.004 | 0.397 | 0.024 | 0.147 |
#> | 1990 | 0.042 | 0.748 | 0.004 | 0.359 | 0.001 | 0.097 |
#> | 2000 | 0.040 | 0.708 | 0.004 | 0.354 | 0.008 | 0.178 |
#> | 2010 | 0.034 | 0.724 | 0.007 | 0.347 | 0.009 | 0.112 |
#> | 2020 | 0.031 | 0.679 | 0.004 | 0.307 | 0.004 | 0.135 |
bp$within.class.sample.predictivity
#> $`1950`
#> 1 2 3 4 5 6
#> 0.015746118 0.039730907 0.038497287 0.439666227 0.295784798 0.033879879
#> 7 8 9 10 11 12
#> 0.051984303 0.094404979 0.066739365 0.022906377 0.023222065 0.029903155
#> 13 14 15 16 17 18
#> 0.005232429 0.215091276 0.222586853 0.030373564 0.105045912 0.107605608
#> 19 20 21 22 23 24
#> 0.446808282 0.633012008 0.183867884 0.559753500 0.087099523 0.681736397
#> 25 26 27 28 29 30
#> 0.399452378 0.172633968 0.786841782 0.883491755 0.330237508 0.400795164
#> 31 32 33 34 35 36
#> 0.470506415 0.689945776 0.840671179 0.479041034 0.069240190 0.143161522
#> 37 38 39 40 41 42
#> 0.296027916 0.471274070 0.457073066 0.703790400 0.821506910 0.214198289
#> 43 44 45 46 47 48
#> 0.154020811 0.489285551 0.154766746 0.368023724 0.967064057 0.536786881
#> 49 50 51 52 53 54
#> 0.040982854 0.160021615 0.496128914 0.695456818 0.849843078 0.055428868
#> 55 56 57 58 59 60
#> 0.023828581 0.188415066 0.220614476 0.749728731 0.297507430 0.121130477
#> 61 62 63 64 65 66
#> 0.307879971 0.259804892 0.055035861 0.143700768 0.711699149 0.074593358
#> 67 68 69 70 71 72
#> 0.006633255 0.161860130 0.154779686 0.543050342 0.208432081 0.463612659
#> 73 74 75 76 77 78
#> 0.112775087 0.124347944 0.285748825 0.213332089 0.013906186 0.049204304
#> 79 80 81 82 83 84
#> 0.124145818 0.451076321 0.221528412 0.123613556 0.190230783 0.099612555
#> 85 86 87 88 89 90
#> 0.770378972 0.793227433 0.010329013 0.048953782 0.310027367 0.095276705
#> 91 92 93 94 95 96
#> 0.397702705 0.517912121 0.553885691 0.453997476 0.263336004 0.327643048
#> 97 98 99 100 101 102
#> 0.101118938 0.109911781 0.374738442 0.695604337 0.335158073 0.541239275
#> 103 104 105 106 107 108
#> 0.207538276 0.011108215 0.438678578 0.728913606 0.070711612 0.097076708
#> 109 110 111 112 113 114
#> 0.573464690 0.765842549 0.752050286 0.933697317 0.499467278 0.262198824
#> 115 116 117 118 119 120
#> 0.511451135 0.740709289 0.845680494 0.834522310 0.342733213 0.223301108
#>
#> $`1960`
#> 1 2 3 4 5 6
#> 0.060499428 0.018961596 0.056329076 0.004703855 0.288643056 0.021723795
#> 7 8 9 10 11 12
#> 0.013703293 0.010165941 0.227803484 0.017794324 0.046043589 0.067095034
#> 13 14 15 16 17 18
#> 0.671508663 0.962001931 0.396885090 0.392074415 0.203903629 0.600537339
#> 19 20 21 22 23 24
#> 0.731640884 0.839862893 0.301154983 0.225923041 0.411174608 0.085250985
#> 25 26 27 28 29 30
#> 0.805630467 0.532418211 0.292184270 0.921257429 0.525725624 0.264305394
#> 31 32 33 34 35 36
#> 0.330406701 0.638144147 0.763898940 0.726109231 0.300384013 0.154019409
#> 37 38 39 40 41 42
#> 0.443707027 0.264620328 0.497661840 0.769669595 0.495086418 0.378178904
#> 43 44 45 46 47 48
#> 0.627248991 0.273669813 0.053783098 0.759692435 0.939456312 0.608037343
#> 49 50 51 52 53 54
#> 0.038087224 0.407710145 0.191085763 0.749794649 0.796031927 0.043814526
#> 55 56 57 58 59 60
#> 0.192632624 0.190927078 0.519511487 0.570496756 0.043941646 0.246100995
#> 61 62 63 64 65 66
#> 0.649896006 0.566158740 0.422092426 0.057898811 0.733128684 0.084228546
#> 67 68 69 70 71 72
#> 0.018800946 0.038855140 0.258580302 0.661813791 0.393307520 0.263453964
#> 73 74 75 76 77 78
#> 0.135678570 0.151031107 0.254437615 0.170458577 0.025882858 0.056722040
#> 79 80 81 82 83 84
#> 0.162922207 0.240768230 0.396669069 0.272272419 0.029556698 0.053508394
#> 85 86 87 88 89 90
#> 0.415543790 0.332871714 0.041126541 0.002000071 0.456230794 0.121220963
#> 91 92 93 94 95 96
#> 0.202976483 0.074051178 0.391454374 0.152815915 0.145643526 0.059938395
#> 97 98 99 100 101 102
#> 0.155999530 0.460591713 0.568274807 0.637567775 0.065385090 0.402244083
#> 103 104 105 106 107 108
#> 0.221395609 0.054319631 0.102601511 0.848377379 0.398413591 0.065100542
#> 109 110 111 112 113 114
#> 0.309528521 0.639316347 0.796010926 0.799516803 0.385606804 0.502543619
#> 115 116 117 118 119 120
#> 0.516932435 0.622828455 0.836200706 0.741291674 0.343191932 0.377383751
#>
#> $`1970`
#> 1 2 3 4 5 6
#> 0.025878232 0.047595607 0.112693775 0.002237434 0.028006311 0.033928264
#> 7 8 9 10 11 12
#> 0.038759776 0.099243058 0.203191144 0.017390380 0.027030358 0.116484020
#> 13 14 15 16 17 18
#> 0.792551422 0.928836304 0.799652546 0.353755590 0.342073432 0.497195206
#> 19 20 21 22 23 24
#> 0.829573879 0.787270408 0.934060237 0.422692185 0.897552190 0.362428243
#> 25 26 27 28 29 30
#> 0.528633708 0.749287315 0.846799168 0.654759324 0.273393697 0.418654473
#> 31 32 33 34 35 36
#> 0.365204546 0.698785362 0.792779516 0.403319202 0.157272577 0.335622270
#> 37 38 39 40 41 42
#> 0.440030320 0.308007166 0.708337163 0.851166801 0.648942537 0.625501286
#> 43 44 45 46 47 48
#> 0.076153589 0.019563909 0.289392333 0.402014545 0.925312805 0.600333258
#> 49 50 51 52 53 54
#> 0.359475370 0.093471077 0.125915872 0.358533593 0.311879081 0.327092727
#> 55 56 57 58 59 60
#> 0.064935197 0.112037173 0.151428606 0.820377264 0.028498158 0.091000355
#> 61 62 63 64 65 66
#> 0.579096955 0.741602212 0.493833125 0.242099897 0.644239989 0.033945070
#> 67 68 69 70 71 72
#> 0.003019020 0.042316312 0.614788054 0.509179418 0.389053778 0.751982092
#> 73 74 75 76 77 78
#> 0.037154800 0.082352154 0.066449262 0.178514468 0.044118015 0.025066060
#> 79 80 81 82 83 84
#> 0.137460514 0.317138329 0.346582169 0.166002740 0.067444371 0.086693696
#> 85 86 87 88 89 90
#> 0.202118381 0.886375811 0.076166047 0.089848132 0.558931434 0.204486631
#> 91 92 93 94 95 96
#> 0.057915497 0.282490641 0.318238723 0.388747368 0.217408770 0.166059587
#> 97 98 99 100 101 102
#> 0.029224419 0.086088428 0.049203955 0.557385869 0.345005755 0.265468321
#> 103 104 105 106 107 108
#> 0.147418567 0.006612725 0.065720468 0.559764445 0.052336197 0.012236853
#> 109 110 111 112 113 114
#> 0.268405489 0.801596287 0.685026572 0.236073716 0.037906772 0.302007390
#> 115 116 117 118 119 120
#> 0.406893587 0.606535848 0.870772810 0.969001428 0.478609279 0.517104497
#>
#> $`1980`
#> 1 2 3 4 5 6
#> 0.102221430 0.102665888 0.078385316 0.015525849 0.074167610 0.064845931
#> 7 8 9 10 11 12
#> 0.036215906 0.141994159 0.116634063 0.039351642 0.068581774 0.086786033
#> 13 14 15 16 17 18
#> 0.434222315 0.700545822 0.807637648 0.064368844 0.553285273 0.370599821
#> 19 20 21 22 23 24
#> 0.544101369 0.650992434 0.942860376 0.461942817 0.571165136 0.435408466
#> 25 26 27 28 29 30
#> 0.676893772 0.372441813 0.455591067 0.305269891 0.267628944 0.415053899
#> 31 32 33 34 35 36
#> 0.631256713 0.726776941 0.068220513 0.309182866 0.128582000 0.337191444
#> 37 38 39 40 41 42
#> 0.490495596 0.358218883 0.425731876 0.261517506 0.866876550 0.496484424
#> 43 44 45 46 47 48
#> 0.169003357 0.360468255 0.227866777 0.779837258 0.959574127 0.432882717
#> 49 50 51 52 53 54
#> 0.050964123 0.517332024 0.411420412 0.317211623 0.662438720 0.003746701
#> 55 56 57 58 59 60
#> 0.152617441 0.163289277 0.199051458 0.509982681 0.092491185 0.128072622
#> 61 62 63 64 65 66
#> 0.681338603 0.607734021 0.666470451 0.051724427 0.681165571 0.070075739
#> 67 68 69 70 71 72
#> 0.030685876 0.092453726 0.753744528 0.374809891 0.018883181 0.428714376
#> 73 74 75 76 77 78
#> 0.072686058 0.104790328 0.160892970 0.119644307 0.003938612 0.037265141
#> 79 80 81 82 83 84
#> 0.123344850 0.265239167 0.206538669 0.174591578 0.066746434 0.113270563
#> 85 86 87 88 89 90
#> 0.813030948 0.329378529 0.143458296 0.095815121 0.498223809 0.364841392
#> 91 92 93 94 95 96
#> 0.212250858 0.274736254 0.165164262 0.356008825 0.384441324 0.410948149
#> 97 98 99 100 101 102
#> 0.223268867 0.335416825 0.228429037 0.403133391 0.521966810 0.400744217
#> 103 104 105 106 107 108
#> 0.010834297 0.023003280 0.356100372 0.672335551 0.293062125 0.064946141
#> 109 110 111 112 113 114
#> 0.724763194 0.744075305 0.877362276 0.681021672 0.619348962 0.496292685
#> 115 116 117 118 119 120
#> 0.776590460 0.733985547 0.829267739 0.498456264 0.555212614 0.170756492
#>
#> $`1990`
#> 1 2 3 4 5 6
#> 0.088483025 0.016288793 0.073277745 0.038076995 0.126269234 0.041503951
#> 7 8 9 10 11 12
#> 0.034365413 0.081024733 0.154352033 0.009224013 0.083188835 0.084609443
#> 13 14 15 16 17 18
#> 0.510975671 0.951100944 0.964931399 0.510958439 0.653902191 0.473537805
#> 19 20 21 22 23 24
#> 0.806171228 0.785540272 0.096121823 0.430480155 0.698607125 0.393896551
#> 25 26 27 28 29 30
#> 0.094275838 0.587382535 0.755998177 0.877378451 0.506925085 0.325314546
#> 31 32 33 34 35 36
#> 0.561792474 0.723121194 0.426420107 0.650725118 0.222286215 0.102704894
#> 37 38 39 40 41 42
#> 0.389374541 0.415366326 0.574014576 0.529150473 0.858704646 0.342349401
#> 43 44 45 46 47 48
#> 0.715251361 0.231425029 0.196704852 0.187598023 0.772477087 0.501034050
#> 49 50 51 52 53 54
#> 0.476830196 0.537237295 0.262494529 0.147330246 0.847855054 0.101012504
#> 55 56 57 58 59 60
#> 0.205068160 0.305090193 0.258782027 0.709016327 0.447689899 0.246274213
#> 61 62 63 64 65 66
#> 0.431416706 0.230163892 0.067959451 0.185338687 0.136880049 0.040302779
#> 67 68 69 70 71 72
#> 0.058558313 0.031297510 0.113425432 0.178385430 0.010628615 0.623231015
#> 73 74 75 76 77 78
#> 0.161507625 0.233634035 0.376678428 0.004687426 0.061164320 0.127292291
#> 79 80 81 82 83 84
#> 0.246286836 0.350698168 0.278753042 0.070356975 0.010613556 0.145591464
#> 85 86 87 88 89 90
#> 0.757773704 0.283446474 0.094831339 0.216861387 0.605052840 0.320300301
#> 91 92 93 94 95 96
#> 0.457613704 0.370057175 0.404426975 0.452971887 0.313313179 0.286180696
#> 97 98 99 100 101 102
#> 0.001755563 0.463073056 0.467744777 0.712133284 0.460506540 0.324295207
#> 103 104 105 106 107 108
#> 0.129838793 0.127240180 0.323403092 0.635666117 0.192569535 0.026570620
#> 109 110 111 112 113 114
#> 0.096414142 0.649940479 0.771518067 0.858365924 0.489348042 0.474594135
#> 115 116 117 118 119 120
#> 0.608977258 0.726314238 0.929196822 0.212554830 0.422680013 0.663729294
#>
#> $`2000`
#> 1 2 3 4 5 6
#> 0.164741079 0.161140002 0.141465309 0.048054649 0.119222720 0.080119005
#> 7 8 9 10 11 12
#> 0.059911002 0.113448641 0.084329499 0.013902706 0.039660737 0.067271488
#> 13 14 15 16 17 18
#> 0.085155881 0.309159457 0.700515270 0.379588109 0.267369719 0.556009616
#> 19 20 21 22 23 24
#> 0.765381863 0.781702734 0.634753869 0.158011048 0.478945362 0.098453220
#> 25 26 27 28 29 30
#> 0.301000739 0.017145228 0.678088469 0.869899442 0.217150144 0.413802008
#> 31 32 33 34 35 36
#> 0.318994609 0.582212986 0.624009812 0.609337818 0.103171560 0.663530655
#> 37 38 39 40 41 42
#> 0.415218679 0.497724940 0.500870721 0.127956631 0.153508914 0.769112988
#> 43 44 45 46 47 48
#> 0.711738568 0.157856829 0.263867354 0.615515787 0.563047556 0.254334840
#> 49 50 51 52 53 54
#> 0.127382273 0.301820770 0.325647486 0.399319843 0.846257029 0.123250055
#> 55 56 57 58 59 60
#> 0.231268613 0.135402592 0.474647207 0.591950210 0.046238924 0.033440116
#> 61 62 63 64 65 66
#> 0.504035198 0.566257023 0.677515980 0.141342329 0.722172015 0.036256699
#> 67 68 69 70 71 72
#> 0.021762910 0.074151166 0.671056909 0.518424903 0.250653609 0.411623560
#> 73 74 75 76 77 78
#> 0.119410931 0.225074573 0.305320383 0.002364057 0.060421722 0.054552877
#> 79 80 81 82 83 84
#> 0.104330728 0.282683452 0.219570227 0.072422868 0.006541142 0.026651617
#> 85 86 87 88 89 90
#> 0.750575417 0.475302877 0.153681829 0.751929711 0.262882774 0.383660432
#> 91 92 93 94 95 96
#> 0.271631837 0.277761659 0.497603826 0.935449091 0.242886994 0.393958870
#> 97 98 99 100 101 102
#> 0.025265419 0.158939051 0.440637586 0.121290009 0.398343753 0.343888249
#> 103 104 105 106 107 108
#> 0.082323999 0.202775484 0.088331837 0.828980216 0.260697645 0.001340717
#> 109 110 111 112 113 114
#> 0.871974779 0.757885100 0.816079157 0.899363896 0.114329248 0.598297641
#> 115 116 117 118 119 120
#> 0.697042338 0.888841503 0.542364642 0.538251561 0.304215600 0.066321808
#>
#> $`2010`
#> 1 2 3 4 5 6
#> 0.072962335 0.053336034 0.064198142 0.017554157 0.052177346 0.049181832
#> 7 8 9 10 11 12
#> 0.058075954 0.069694620 0.030983020 0.010913150 0.070657203 0.076467952
#> 13 14 15 16 17 18
#> 0.404402133 0.910281867 0.485895416 0.314292437 0.230557980 0.409467520
#> 19 20 21 22 23 24
#> 0.840653993 0.699909181 0.570553113 0.749057868 0.319974308 0.173907818
#> 25 26 27 28 29 30
#> 0.324206105 0.053606637 0.893217887 0.944418611 0.124849146 0.364116236
#> 31 32 33 34 35 36
#> 0.458039773 0.582439687 0.705618384 0.389818295 0.132225462 0.404389696
#> 37 38 39 40 41 42
#> 0.434513718 0.046826509 0.414755291 0.560770078 0.049189228 0.768477688
#> 43 44 45 46 47 48
#> 0.697256912 0.307997216 0.247209216 0.856657835 0.910043573 0.660258390
#> 49 50 51 52 53 54
#> 0.007605343 0.154752642 0.567548497 0.895140321 0.218048191 0.057255604
#> 55 56 57 58 59 60
#> 0.033636291 0.116557704 0.449557606 0.783127394 0.214720763 0.149575795
#> 61 62 63 64 65 66
#> 0.289373239 0.765082601 0.253529706 0.226316134 0.005966895 0.036136279
#> 67 68 69 70 71 72
#> 0.035106551 0.019345964 0.554675518 0.349499516 0.114667742 0.220516750
#> 73 74 75 76 77 78
#> 0.092220497 0.093773392 0.087333118 0.007769313 0.002270097 0.044719833
#> 79 80 81 82 83 84
#> 0.105993832 0.257137982 0.140612036 0.028313567 0.030631505 0.055359947
#> 85 86 87 88 89 90
#> 0.935762762 0.082356139 0.058925638 0.485880563 0.438212077 0.539917042
#> 91 92 93 94 95 96
#> 0.330524541 0.574432957 0.251139610 0.551101509 0.354307454 0.395516961
#> 97 98 99 100 101 102
#> 0.191024329 0.432341057 0.452667291 0.148126152 0.052022591 0.233455921
#> 103 104 105 106 107 108
#> 0.145768512 0.015681579 0.038088748 0.347777631 0.087163167 0.019657156
#> 109 110 111 112 113 114
#> 0.807584441 0.528042783 0.731135071 0.881031915 0.014411555 0.394700865
#> 115 116 117 118 119 120
#> 0.635443073 0.816384900 0.812357562 0.719929923 0.366473221 0.248178246
#>
#> $`2020`
#> 1 2 3 4 5 6 7
#> 0.05259444 0.14852527 0.10015323 0.07743033 0.05232701 0.03122956 0.04160198
#> 8 9 10 11 12 13 14
#> 0.05010950 0.10443187 0.04009211 0.01072308 0.04005989 0.18742327 0.30594779
#> 15 16 17 18 19 20 21
#> 0.03176701 0.43045390 0.13668456 0.09568843 0.67240720 0.68705733 0.83620456
#> 22 23 24 25 26 27 28
#> 0.69317185 0.65425361 0.10460967 0.05974724 0.37821238 0.85489025 0.58447004
#> 29 30 31 32 33 34 35
#> 0.23490155 0.27375184 0.45852482 0.47946140 0.57908811 0.53154998 0.05459656
#> 36 37 38 39 40 41 42
#> 0.28487328 0.37078226 0.22387021 0.40476458 0.61198086 0.74054872 0.63076832
#> 43 44 45 46 47 48 49
#> 0.76254819 0.55147972 0.31859377 0.87930200 0.68125736 0.50485975 0.25148614
#> 50 51 52 53 54 55 56
#> 0.40440403 0.17191401 0.73498157 0.49306386 0.14785562 0.08800155 0.17110704
#> 57 58 59 60 61 62 63
#> 0.47278607 0.66627381 0.21137850 0.05079902 0.19176583 0.22713882 0.27276147
#> 64 65 66 67 68 69 70
#> 0.24212634 0.68859875 0.03462458 0.02257600 0.16896710 0.62940177 0.18557097
#> 71 72 73 74 75 76 77
#> 0.29648063 0.50636365 0.02693161 0.17227247 0.07831390 0.13730714 0.01769318
#> 78 79 80 81 82 83 84
#> 0.01391310 0.09199678 0.25426887 0.26384462 0.26394779 0.03801322 0.05413875
#> 85 86 87 88 89 90 91
#> 0.66328552 0.67198819 0.29222360 0.01155712 0.69077427 0.50051805 0.16226909
#> 92 93 94 95 96 97 98
#> 0.39147082 0.61446740 0.27477097 0.11739605 0.11816590 0.07481505 0.36807143
#> 99 100 101 102 103 104 105
#> 0.32100968 0.07039846 0.22869381 0.24433082 0.13064224 0.03949532 0.07186804
#> 106 107 108 109 110 111 112
#> 0.89737437 0.28778021 0.03224334 0.46371343 0.52007709 0.87300925 0.88940864
#> 113 114 115 116 117 118 119
#> 0.31988056 0.40797130 0.65332134 0.75136809 0.82957851 0.78105957 0.26858419
#> 120
#> 0.06873887
#>